==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "File" : "Фајл",
    "File created" : "Фајл направљен",
    "File updated" : "Фајл измењен",
    "File renamed" : "Фајл преименован",
    "File deleted" : "Фајл обрисан",
    "File accessed" : "Фајлу приступљено",
    "File copied" : "Фајл копиран",
    "Tag assigned" : "Додељена ознака",
    "Someone" : "Неко",
    "%s created %s" : "%s је направио %s",
    "%s modified %s" : "%s је изменио %s",
    "%s deleted %s" : "%s је обрисао %s",
    "%s accessed %s" : "%s је приступио %s",
    "%s renamed %s" : "%s је преименовао %s",
    "%s copied %s" : "%s је копирао %s",
    "%s assigned %s to %s" : "%s је доделио %s на %s",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Entity %s does not exist" : "Ентитет %s не постоји",
    "Entity %s is invalid" : "Ентитет %s није исправан",
    "No events are chosen." : "Није одабран ниједан догађај.",
    "Entity %s has no event %s" : "Ентитет %s нема ниједан догађај %s",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "At least one check needs to be provided" : "Треба да се зада бар једна провера",
    "The provided operation data is too long" : "Наведени операциони подаци су сувише дугачки",
    "Invalid check provided" : "Задата неисправна потврда",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
    "The provided check value is too long" : "Наведена вредност за проверу је сувише дугачка",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Flow" : "Ток",
    "Nextcloud workflow engine" : "Некстклаудов мотор радног тока",
    "Select a filter" : "Одаберите филтер",
    "Select a comparator" : "Одаберите компаратор",
    "Remove filter" : "Уклони филтер",
    "Audio" : "Звук",
    "Folder" : "Фасцикла",
    "Images" : "Слике",
    "Office documents" : "Канцеларијски документи",
    "PDF documents" : "PDF документи",
    "Video" : "Видео снимак",
    "Custom MIME type" : "Прилагођени MIME тип",
    "Custom mimetype" : "Произвољни MIME тип",
    "Select a file type" : "Одаберите тип фајла",
    "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
    "Please enter a valid time span" : "Унесите исправан временски распон",
    "Files WebDAV" : "WebDAV фајлови",
    "Custom URL" : "Произвољна адреса",
    "Select a request URL" : "Одабери адресу захтева",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "Thunderbird & Outlook addons" : "Додаци за Thunderbird & Outlook",
    "Custom user agent" : "Произвољни агент захтева",
    "Select a user agent" : "Одаберите агента захтева",
    "Select groups" : "Изаберите групе",
    "Groups" : "Групе",
    "Type to search for group …" : "Куцајте да претражите групу",
    "Select a trigger" : "Изаберите окидач",
    "At least one event must be selected" : "Мора бити одабран бар један догађај",
    "Add new flow" : "Додај нови ток",
    "The configuration is invalid" : "Конфигурација је неисправна",
    "Active" : "Активан",
    "Save" : "Сачувај",
    "When" : "Када",
    "and" : "и",
    "Add a new filter" : "Додај нови филтер",
    "Cancel" : "Откажи",
    "Delete" : "Обриши",
    "Available flows" : "Доступни токови",
    "For details on how to write your own flow, check out the development documentation." : "За детаље како написати сопствени ток, погледајте програмерску документацију.",
    "No flows installed" : "Није инсталиран ниједан ток",
    "Ask your administrator to install new flows." : "Затражите од свог администратора да инсталира нове токове.",
    "More flows" : "Још токова",
    "Browse the App Store" : "Прегледајте Продавницу апликација",
    "Show less" : "Прикажи мање",
    "Show more" : "Прикажи више",
    "Configured flows" : "Подешени токови",
    "Your flows" : "Ваши токови",
    "No flows configured" : "Није конфигурисан ниједан ток",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "is" : "је",
    "is not" : "није",
    "File name" : "Име фајла",
    "File MIME type" : "MIME тип фајла",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Request URL" : "Адреса захтева",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Request user agent" : "Кориснички агент захтева",
    "Group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "File" : "Фајл",
    "File created" : "Фајл направљен",
    "File updated" : "Фајл измењен",
    "File renamed" : "Фајл преименован",
    "File deleted" : "Фајл обрисан",
    "File accessed" : "Фајлу приступљено",
    "File copied" : "Фајл копиран",
    "Tag assigned" : "Додељена ознака",
    "Someone" : "Неко",
    "%s created %s" : "%s је направио %s",
    "%s modified %s" : "%s је изменио %s",
    "%s deleted %s" : "%s је обрисао %s",
    "%s accessed %s" : "%s је приступио %s",
    "%s renamed %s" : "%s је преименовао %s",
    "%s copied %s" : "%s је копирао %s",
    "%s assigned %s to %s" : "%s је доделио %s на %s",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Entity %s does not exist" : "Ентитет %s не постоји",
    "Entity %s is invalid" : "Ентитет %s није исправан",
    "No events are chosen." : "Није одабран ниједан догађај.",
    "Entity %s has no event %s" : "Ентитет %s нема ниједан догађај %s",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "At least one check needs to be provided" : "Треба да се зада бар једна провера",
    "The provided operation data is too long" : "Наведени операциони подаци су сувише дугачки",
    "Invalid check provided" : "Задата неисправна потврда",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
    "The provided check value is too long" : "Наведена вредност за проверу је сувише дугачка",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Flow" : "Ток",
    "Nextcloud workflow engine" : "Некстклаудов мотор радног тока",
    "Select a filter" : "Одаберите филтер",
    "Select a comparator" : "Одаберите компаратор",
    "Remove filter" : "Уклони филтер",
    "Audio" : "Звук",
    "Folder" : "Фасцикла",
    "Images" : "Слике",
    "Office documents" : "Канцеларијски документи",
    "PDF documents" : "PDF документи",
    "Video" : "Видео снимак",
    "Custom MIME type" : "Прилагођени MIME тип",
    "Custom mimetype" : "Произвољни MIME тип",
    "Select a file type" : "Одаберите тип фајла",
    "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
    "Please enter a valid time span" : "Унесите исправан временски распон",
    "Files WebDAV" : "WebDAV фајлови",
    "Custom URL" : "Произвољна адреса",
    "Select a request URL" : "Одабери адресу захтева",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "Thunderbird & Outlook addons" : "Додаци за Thunderbird & Outlook",
    "Custom user agent" : "Произвољни агент захтева",
    "Select a user agent" : "Одаберите агента захтева",
    "Select groups" : "Изаберите групе",
    "Groups" : "Групе",
    "Type to search for group …" : "Куцајте да претражите групу …",
    "Select a trigger" : "Изаберите окидач",
    "At least one event must be selected" : "Мора бити одабран бар један догађај",
    "Add new flow" : "Додај нови ток",
    "The configuration is invalid" : "Конфигурација је неисправна",
    "Active" : "Активан",
    "Save" : "Сачувај",
    "When" : "Када",
    "and" : "и",
    "Add a new filter" : "Додај нови филтер",
    "Cancel" : "Откажи",
    "Delete" : "Обриши",
    "Available flows" : "Доступни токови",
    "For details on how to write your own flow, check out the development documentation." : "За детаље како написати сопствени ток, погледајте програмерску документацију.",
    "No flows installed" : "Није инсталиран ниједан ток",
    "Ask your administrator to install new flows." : "Затражите од свог администратора да инсталира нове токове.",
    "More flows" : "Још токова",
    "Browse the App Store" : "Прегледајте Продавницу апликација",
    "Show less" : "Прикажи мање",
    "Show more" : "Прикажи више",
    "Configured flows" : "Подешени токови",
    "Your flows" : "Ваши токови",
    "No flows configured" : "Није конфигурисан ниједан ток",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "is" : "је",
    "is not" : "није",
    "File name" : "Име фајла",
    "File MIME type" : "MIME тип фајла",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Request URL" : "Адреса захтева",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Request user agent" : "Кориснички агент захтева",
    "Group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе",
    "Type to search for group …" : "Куцајте да претражите групу"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
